===============
Parrot Api Core
===============


.. image:: https://img.shields.io/pypi/v/parrot_integrations_core.svg
        :target: https://pypi.python.org/pypi/parrot_integrations_core

.. image:: https://img.shields.io/travis/perrystallings/parrot_integrations_core.svg
        :target: https://travis-ci.com/perrystallings/parrot_integrations_core

.. image:: https://readthedocs.org/projects/parrot-integrations-core/badge/?version=latest
        :target: https://parrot-integrations-core.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/perrystallings/parrot_integrations_core/shield.svg
     :target: https://pyup.io/repos/github/perrystallings/parrot_integrations_core/
     :alt: Updates



Python API Project Framework


* Free software: MIT license
* Documentation: https://parrot-integrations-core.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
